@@ -28,6 +28,8 @@ struct device;
 struct station;
 struct network;
 struct scan_bss;
+struct handshake_state;
+struct erp_cache_entry;
 
 void network_connected(struct network *network);
 void network_disconnected(struct network *network);
@@ -39,19 +41,30 @@ struct network *network_create(struct station *station, const char *ssid,
 const char *network_get_ssid(const struct network *network);
 const char *network_get_path(const struct network *network);
 enum security network_get_security(const struct network *network);
-const uint8_t *network_get_psk(struct network *network);
-const char *network_get_passphrase(const struct network *network);
 bool network_set_passphrase(struct network *network, const char *passphrase);
-struct l_queue *network_get_secrets(const struct network *network);
 int network_get_signal_strength(const struct network *network);
 struct l_settings *network_get_settings(const struct network *network);
+struct station *network_get_station(const struct network *network);
 
 bool network_set_psk(struct network *network, const uint8_t *psk);
-void network_sync_psk(struct network *network);
+
+int network_set_transition_disable(struct network *network,
+					const uint8_t *td, size_t len);
+
+int network_handshake_setup(struct network *network, struct scan_bss *bss,
+						struct handshake_state *hs);
+
+void network_sync_settings(struct network *network);
 
 const struct network_info *network_get_info(const struct network *network);
 void network_set_info(struct network *network, struct network_info *info);
+void network_set_force_default_owe_group(struct network *network);
+bool network_get_force_default_owe_group(struct network *network);
 
+bool network_update_known_frequencies(struct network *network);
+
+int network_can_connect_bss(struct network *network,
+						const struct scan_bss *bss);
 int network_autoconnect(struct network *network, struct scan_bss *bss);
 void network_connect_failed(struct network *network, bool in_handshake);
 bool network_bss_add(struct network *network, struct scan_bss *bss);
@@ -77,10 +90,11 @@ struct l_dbus_message *network_connect_new_hidden_network(
 
 void network_blacklist_add(struct network *network, struct scan_bss *bss);
 
-const struct iovec *network_get_extra_ies(struct network *network,
-						size_t *num_elems);
-
-bool network_has_erp_identity(struct network *network);
+struct erp_cache_entry *network_get_erp_cache(struct network *network);
 
 const struct l_queue_entry *network_bss_list_get_entries(
-						struct network *network);
+						const struct network *network);
+
+struct l_dbus_message *__network_connect(struct network *network,
+						struct scan_bss *bss,
+						struct l_dbus_message *message);
